.. arguments:

Global Arguments
================

In addition to each operations having its own arguments, there are a number of keyword arguments available in all facts, operations and deploys.

.. note::
    With the exception of ``name`` these are prefixed with ``_`` to avoid clashes with other operation and deploy arguments.

.. include:: _deploy_globals.rst
